package com.fastest.pass.login.presentation.viewmodels

import android.util.Log
import androidx.lifecycle.ViewModel
import androidx.lifecycle.viewModelScope
import com.fastest.pass.login.data.model.LoginResult
import com.fastest.pass.login.domain.usecase.LoginUseCase
import com.fastest.pass.login.utils.LoginRoute
import dagger.hilt.android.lifecycle.HiltViewModel
import kotlinx.coroutines.flow.MutableStateFlow
import kotlinx.coroutines.launch
import javax.inject.Inject

@HiltViewModel
class LoginViewModel @Inject constructor(
    private val loginUseCase: LoginUseCase
) : ViewModel() {

    private val _router = MutableStateFlow<LoginRoute>(LoginRoute.OpenNoneScreen)
    val router: MutableStateFlow<LoginRoute> = _router

    private val _loginResult = MutableStateFlow<LoginResult>(LoginResult.None)
    val loginResult: MutableStateFlow<LoginResult> = _loginResult

    fun navigateTo(loginRoute: LoginRoute) {
        _router.value = loginRoute
    }

    fun onLoginClicked(email: String, password: String) {
        _loginResult.value = LoginResult.Loading
        viewModelScope.launch {
            Log.d("test_api_login", "onLoginClicked => LoginViewModel")
            val loginResult = loginUseCase(email, password)
            Log.d("loginResult", "loginResult = $loginResult")
        }
    }
}